@@ -4,23 +4,34 @@
     anonymous_parameters,
     arithmetic_overflow,
     array_into_iter,
+    asm_sub_register,
     bindings_with_variant_name,
+    broken_intra_doc_links,
+    cenum_impl_drop_cast,
+    clashing_extern_declarations,
     coherence_leak_check,
     conflicting_repr_hints,
+    confusable_idents,
     const_err,
+    const_evaluatable_unchecked,
+    const_item_mutation,
     dead_code,
     deprecated,
     deprecated_in_future,
+    drop_bounds,
     ellipsis_inclusive_range_patterns,
     explicit_outlives_requirements,
     exported_private_dependencies,
+    function_item_references,
     ill_formed_attribute_input,
     illegal_floating_point_literal_pattern,
     improper_ctypes,
+    improper_ctypes_definitions,
     incomplete_features,
+    incomplete_include,
     indirect_structural_match,
     inline_no_sanitize,
-    invalid_codeblock_attribute,
+    invalid_codeblock_attributes,
     invalid_type_param_default,
     invalid_value,
     irrefutable_let_patterns,
@@ -28,40 +39,50 @@
     late_bound_lifetime_arguments,
     macro_expanded_macro_exports_accessed_by_absolute_paths,
     meta_variable_misuse,
+    missing_abi,
     missing_copy_implementations,
     missing_crate_level_docs,
     missing_docs,
     missing_fragment_specifier,
+    mixed_script_confusables,
     mutable_borrow_reservation_conflict,
     mutable_transmutes,
     no_mangle_const_items,
     no_mangle_generic_items,
     non_ascii_idents,
+    non_autolinks,
     non_camel_case_types,
     non_shorthand_field_patterns,
     non_snake_case,
     non_upper_case_globals,
+    nontrivial_structural_match,
     order_dependent_trait_objects,
     overflowing_literals,
-    overlapping_patterns,
+    overlapping_range_endpoints,
+    panic_fmt,
     path_statements,
     patterns_in_fns_without_body,
+    pointer_structural_match,
     private_doc_tests,
     private_in_public,
+    private_intra_doc_links,
     proc_macro_derive_resolution_fallback,
     pub_use_of_private_extern_crate,
     redundant_semicolons,
     safe_packed_borrows,
     soft_unstable,
     stable_features,
+    temporary_cstring_as_ptr,
     trivial_bounds,
     trivial_casts,
     trivial_numeric_casts,
     type_alias_bounds,
     tyvar_behind_raw_pointer,
+    unaligned_references,
     uncommon_codepoints,
     unconditional_panic,
     unconditional_recursion,
+    uninhabited_static,
     unknown_crate_types,
     unnameable_test_items,
     unreachable_code,
@@ -70,11 +91,13 @@
     unsafe_code,
     unstable_features,
     unstable_name_collisions,
+    unsupported_naked_functions,
     unused_allocation,
     unused_assignments,
     unused_attributes,
     unused_braces,
     unused_comparisons,
+    unused_crate_dependencies,
     unused_doc_comments,
     unused_extern_crates,
     unused_features,
@@ -89,6 +112,7 @@
     unused_qualifications,
     unused_unsafe,
     unused_variables,
+    useless_deprecated,
     where_clauses_object_safety,
     while_true
 )]
@@ -96,8 +120,8 @@
 #![allow(
     bare_trait_objects,
     box_pointers,
+    invalid_html_tags,
     elided_lifetimes_in_paths,
-    intra_doc_link_resolution_failure,
     missing_doc_code_examples,
     missing_debug_implementations,
     single_use_lifetimes,
